pygeodesy.auxilats

Package pygeodesy :: Package auxilats |
[frames] | no frames]

# Package auxilats

Classes AuxAngle, AuxDLat, AuxDST and AuxLat transcoded to Python from Karney's C++ class AuxAngle, DAuxLatitude, DST, repectively AuxLatitude all in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Note: Class AuxDST requires numpy to be installed, version 1.16 or newer.

See Also: Auxiliary latitudes and On auxiliary latitudes.

Version: 25.12.02

Submodules
pygeodesy.auxilats._CX_4: Coefficients for `_AUXLATITUDE_ORDER` 4 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s. pygeodesy.auxilats._CX_6: Coefficients for `_AUXLATITUDE_ORDER` 6 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s. pygeodesy.auxilats._CX_8: Coefficients for `_AUXLATITUDE_ORDER` 8 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s. pygeodesy.auxilats._CX_Rs: (INTERNAL) Classes `_Rcoeffs`, `_Rdict` and `_Rtuple` to store the deferred Python versions of coefficients from Karney's C++ class AuxLatitude. pygeodesy.auxilats.__main__: Print auxilats version, etc. pygeodesy.auxilats.auxAngle: (INTERNAL) Auxiliary latitudes' base classes, constants and functions. pygeodesy.auxilats.auxDLat: Class AuxDLat transcoded to Python from Karney's C++ class DAuxLatitude in GeographicLib version 2.2+. pygeodesy.auxilats.auxDST: Discrete Sine Transforms (AuxDST) in Python, transcoded from Karney's C++ class DST in GeographicLib version 2.2+. pygeodesy.auxilats.auxLat: Class AuxLat transcoded to Python from Karney's C++ class AuxLatitude in GeographicLib version 2.2+. pygeodesy.auxilats.auxily: (INTERNAL) Auxiliary latitudes' classes, constants and functions.

Classes
| AuxAngle An accurate representation of angles
| AuxBeta A Parametric, Auxiliary latitude.
| AuxChi A Conformal, Auxiliary latitude.
| AuxMu A Rectifying, Auxiliary latitude.
| AuxPhi A Geodetic or Geographic, Auxiliary latitude.
| AuxTheta A Geocentric, Auxiliary latitude.
| AuxXi An Authalic, Auxiliary latitude.
| AuxDLat Class to compute `Divided Differences` of Auxiliary latitudes and other `Divided Differences` needed for RhumbAux and RhumbLineAux calculations.
| AuxDST Discrete Sine Transforms (DST) for Auxiliary latitudes.
| AuxLat Base class for accurate conversion between Auxiliary latitudes on an ellipsoid.

Variables
| Aux = `Aux()`